@@ -3,9 +3,11 @@
 # This software was developed at the University of Colorado's Laboratory for Atmospheric and Space Physics.
 # Verify current version before use at: https://github.com/MAVENSDC/Pydivide
 
+import logging
 import re
 import os
 from . import download_files_utilities as utils
+from .file_regex import kp_regex, l2_regex
 import numpy as np
 import collections
 
@@ -35,10 +37,10 @@ def param_list(kp):
             param_list_.append("#%3d %s" % (index, base_tag))
             index += 1
         else:
-            print('*****WARNING*****')
-            print('Returning INCOMPLETE Parameter List')
-            print('Base tag neither DataFrame nor Series')
-            print('Plese check read_insitu_file definition')
+            logging.warning('*****WARNING*****')
+            logging.warning('Returning INCOMPLETE Parameter List')
+            logging.warning('Base tag neither DataFrame nor Series')
+            logging.warning('Plese check read_insitu_file definition')
 
     return param_list_
 
@@ -63,8 +65,6 @@ def param_range(kp, iuvs=None):
         None: prints information to screen
     '''
 
-    import numpy as np
-
     # First, the case where insitu data are provided
     print("The loaded insitu KP data set contains data between")
     print("   %s and %s" % (np.array(kp['TimeString'])[0], np.array(kp['TimeString'])[-1]))
@@ -130,7 +130,6 @@ def range_select(kp, time=None, parameter=None, maximum=None, minimum=None):
     ToDo: compartmentalize the filtering and/or argument checks.
     '''
     from datetime import datetime
-    import numpy as np
 
     #  Initialize the filter_list
     filter_list = []
@@ -282,7 +281,7 @@ def range_select(kp, time=None, parameter=None, maximum=None, minimum=None):
                 else:
                     nparam = len(parameter)
                     for param in parameter:
-                        a, b = get_inst_obs_labels(kp, parameter)
+                        a, b = get_inst_obs_labels(kp, param)
                         inst.append(a)
                         obs.append(b)
 
@@ -378,8 +377,6 @@ def find_param_from_index(kp, index):
         (e.g., LPW.EWAVE_LOW_FREQ)
     '''
 
-    import re
-
     index = '#%3d' % int(index)
     plist = param_list(kp)
     found = False
@@ -415,14 +412,13 @@ def remove_inst_tag(df):
 
 def get_latest_files_from_date_range(date1, date2):
     from datetime import timedelta
-    import datetime
 
     mvn_root_data_dir = utils.get_root_data_dir()
     maven_data_dir = os.path.join(mvn_root_data_dir, 'maven', 'data', 'sci', 'kp', 'insitu')
 
     # Each file starts at midnight, so lets cut off the hours and just pay attention to the days
     date1 = date1.replace(hour=0, minute=0, second=0)
-    date2 = date2.replace(hour=0, minute=0, second=0) + datetime.timedelta(days=1)
+    date2 = date2.replace(hour=0, minute=0, second=0) + timedelta(days=1)
 
     time_spanned = date2 - date1
     num_days = time_spanned.days
@@ -477,14 +473,13 @@ def get_latest_files_from_date_range(date1, date2):
 
 def get_latest_iuvs_files_from_date_range(date1, date2):
     from datetime import timedelta
-    import datetime
 
     mvn_root_data_dir = utils.get_root_data_dir()
     maven_data_dir = os.path.join(mvn_root_data_dir, 'maven', 'data', 'sci', 'kp', 'iuvs')
 
     # Each file starts at midnight, so lets cut off the hours and just pay attention to the days
     date1 = date1.replace(hour=0, minute=0, second=0)
-    date2 = date2.replace(day=date2.day, hour=0, minute=0, second=0) + datetime.timedelta(days=1)
+    date2 = date2.replace(day=date2.day, hour=0, minute=0, second=0) + timedelta(days=1)
 
     time_spanned = date2 - date1
     num_days = time_spanned.days
@@ -709,54 +704,6 @@ def get_header_info(filename):
     return names, inst
 
 
-# kp pattern
-kp_pattern = (r'^mvn_(?P<{0}>kp)_'
-              '(?P<{1}>insitu|iuvs)'
-              '(?P<{2}>|_[a-zA-Z0-9\-]+)_'
-              '(?P<{3}>[0-9]{{4}})'
-              '(?P<{4}>[0-9]{{2}})'
-              '(?P<{5}>[0-9]{{2}})'
-              '(?P<{6}>|[t|T][0-9]{{6}})_'
-              'v(?P<{7}>[0-9]+)_r(?P<{8}>[0-9]+)\.'
-              '(?P<{9}>tab)'
-              '(?P<{10}>\.gz)*').format('instrument',
-                                        'level',
-                                        'description',
-                                        'year',
-                                        'month',
-                                        'day',
-                                        'time',
-                                        'version',
-                                        'revision',
-                                        'extension',
-                                        'gz')
-
-kp_regex = re.compile(kp_pattern)
-
-l2_pattern = (r'^mvn_(?P<{0}>[a-zA-Z0-9]+)_'
-              '(?P<{1}>l[a-zA-Z0-9]+)'
-              '(?P<{2}>|_[a-zA-Z0-9\-]+)_'
-              '(?P<{3}>[0-9]{{4}})'
-              '(?P<{4}>[0-9]{{2}})'
-              '(?P<{5}>[0-9]{{2}})'
-              '(?P<{6}>|T[0-9]{{6}}|t[0-9]{{6}})_'
-              'v(?P<{7}>[0-9]+)_'
-              'r(?P<{8}>[0-9]+)\.'
-              '(?P<{9}>cdf|xml|sts|md5)'
-              '(?P<{10}>\.gz)*').format('instrument',
-                                        'level',
-                                        'description',
-                                        'year',
-                                        'month',
-                                        'day',
-                                        'time',
-                                        'version',
-                                        'revision',
-                                        'extension',
-                                        'gz')
-l2_regex = re.compile(l2_pattern)
-
-
 def initialize_list(the_list):
     index = 0
     for i in the_list:
