@@ -1,11 +1,10 @@
-
 import logging
 import pandas as pd
 import numpy as np
-
 from pyspedas.analysis.time_clip import time_clip as tclip
 from pytplot import store_data, options
 
+
 def mms_load_eph_tplot(filenames, level='def', probe='1', datatypes=['pos', 'vel'], suffix='', trange=None):
     """
     Helper routine for loading state data (ASCII files from the SDC); not meant to be called directly; see pyspedas.mms.state instead
@@ -45,7 +44,6 @@ def mms_load_eph_tplot(filenames, level='def', probe='1', datatypes=['pos', 'vel
         options(prefix + '_' + level + 'eph_pos' + suffix, 'ytitle', 'MMS'+str(probe)+' position')
         options(prefix + '_' + level + 'eph_pos' + suffix, 'ysubtitle', '[km]')
         options(prefix + '_' + level + 'eph_pos' + suffix, 'legend_names', ['X ECI', 'Y ECI', 'Z ECI'])
-        options(prefix + '_' + level + 'eph_pos' + suffix, 'color', ['b', 'g', 'r'])
 
     if 'vel' in datatypes:
         store_data(prefix + '_' + level + 'eph_vel' + suffix, data={'x': time_values, 'y': np.transpose(np.array([vx_values, vy_values, vz_values]))})
@@ -53,5 +51,4 @@ def mms_load_eph_tplot(filenames, level='def', probe='1', datatypes=['pos', 'vel
         options(prefix + '_' + level + 'eph_vel' + suffix, 'ytitle', 'MMS'+str(probe)+' velocity')
         options(prefix + '_' + level + 'eph_vel' + suffix, 'ysubtitle', '[km/s]')
         options(prefix + '_' + level + 'eph_vel' + suffix, 'legend_names', ['Vx ECI', 'Vy ECI', 'Vz ECI'])
-        options(prefix + '_' + level + 'eph_vel' + suffix, 'color', ['b', 'g', 'r'])
 
