@@ -1,3 +1,4 @@
+import logging
 import os
 import re
 import shutil
@@ -9,6 +10,7 @@ from dateutil.parser import parse
 
 from datetime import timedelta
 
+
 def mms_get_local_files(probe, instrument, data_rate, level, datatype, trange, mirror=False):
 
     """
@@ -51,7 +53,6 @@ def mms_get_local_files(probe, instrument, data_rate, level, datatype, trange, m
     else:
         data_dir = CONFIG['local_data_dir']
 
-
     # directory and file name search patterns
     #   -assume directories are of the form:
     #      (srvy, SITL): spacecraft/instrument/rate/level[/datatype]/year/month/
@@ -79,12 +80,16 @@ def mms_get_local_files(probe, instrument, data_rate, level, datatype, trange, m
         else:
             full_path = os.sep.join([re.escape(local_dir), file_name])
 
+        # check for extra /'s in the path
+        if '//' in full_path:
+            full_path = full_path.replace('//', '/')
+
         regex = re.compile(full_path)
         for root, dirs, files in os.walk(data_dir):
             for file in files:
                 this_file = os.sep.join([root, file])
-                if CONFIG['debug_mode']: print('Checking ' + this_file)
-                if CONFIG['debug_mode']: print('against: ' + full_path)
+                if CONFIG['debug_mode']: logging.info('Checking ' + this_file)
+                if CONFIG['debug_mode']: logging.info('against: ' + full_path)
                 
                 matches = regex.match(this_file)
                 if matches:
@@ -110,12 +115,12 @@ def mms_get_local_files(probe, instrument, data_rate, level, datatype, trange, m
         # need to copy files from network mirror to local data directory
         for file in local_files:
             local_file = file.replace(mirror_dir, local_dir)
-            if CONFIG['debug_mode']: print('Copying ' + file + ' to ' + local_file)
+            if CONFIG['debug_mode']: logging.info('Copying ' + file + ' to ' + local_file)
             shutil.copyfile(file, local_file)
             local_files_copied.append(local_file)
         local_files = local_files_copied
 
     for file in local_files:
-        print('Loading: ' + file)
+        logging.info('Loading: ' + file)
 
-    return local_files
\ No newline at end of file
+    return local_files
